@@ -606,7 +606,7 @@ void synthv1_jack::sessionEvent ( void *pvSessionArg )
 
 	QStringList args;
 	args << QCoreApplication::applicationFilePath();
-	args << QString("\"${SESSION_DIR}%1\"").arg(sSessionFile);
+	args << QString("${SESSION_DIR}%1").arg(sSessionFile);
 
 	synthv1_param::savePreset(this,
 		QFileInfo(sSessionDir, sSessionFile).absoluteFilePath(), true);
