@@ -1,7 +1,7 @@
 // synthv1widget_controls.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -101,26 +101,25 @@ const synthv1widget_controls::Names& synthv1widget_controls::controllerNames (vo
 		{ 45, QT_TR_NOOP("Effect Control 2 (fine)") },
 		{ 64, QT_TR_NOOP("Hold Pedal (on/off)") },
 		{ 65, QT_TR_NOOP("Portamento (on/off)") },
-		{ 66, QT_TR_NOOP("Sustenuto Pedal (on/off)") },
+		{ 66, QT_TR_NOOP("Sostenuto Pedal (on/off)") },
 		{ 67, QT_TR_NOOP("Soft Pedal (on/off)") },
 		{ 68, QT_TR_NOOP("Legato Pedal (on/off)") },
 		{ 69, QT_TR_NOOP("Hold 2 Pedal (on/off)") },
 		{ 70, QT_TR_NOOP("Sound Variation") },
-		{ 71, QT_TR_NOOP("Sound Timbre") },
-		{ 72, QT_TR_NOOP("Sound Release Time") },
-		{ 73, QT_TR_NOOP("Sound Attack Time") },
-		{ 74, QT_TR_NOOP("Sound Brightness") },
-		{ 75, QT_TR_NOOP("Sound Control 6") },
-		{ 76, QT_TR_NOOP("Sound Control 7") },
-		{ 77, QT_TR_NOOP("Sound Control 8") },
-		{ 78, QT_TR_NOOP("Sound Control 9") },
-		{ 79, QT_TR_NOOP("Sound Control 10") },
+		{ 71, QT_TR_NOOP("Filter Resonance") },
+		{ 72, QT_TR_NOOP("Release Time") },
+		{ 73, QT_TR_NOOP("Attack Time") },
+		{ 74, QT_TR_NOOP("Brightness") },
+		{ 75, QT_TR_NOOP("Decay Time") },
+		{ 76, QT_TR_NOOP("Vibrato Rate") },
+		{ 77, QT_TR_NOOP("Vibrato Depth") },
+		{ 78, QT_TR_NOOP("Vibrato Delay") },
 		{ 80, QT_TR_NOOP("General Purpose Button 1 (on/off)") },
 		{ 81, QT_TR_NOOP("General Purpose Button 2 (on/off)") },
 		{ 82, QT_TR_NOOP("General Purpose Button 3 (on/off)") },
 		{ 83, QT_TR_NOOP("General Purpose Button 4 (on/off)") },
 		{ 91, QT_TR_NOOP("Effects Level") },
-		{ 92, QT_TR_NOOP("Tremulo Level") },
+		{ 92, QT_TR_NOOP("Tremolo Level") },
 		{ 93, QT_TR_NOOP("Chorus Level") },
 		{ 94, QT_TR_NOOP("Celeste Level") },
 		{ 95, QT_TR_NOOP("Phaser Level") },
