@@ -142,8 +142,8 @@ void synthv1widget_jack::updateDirtyPreset ( bool bDirtyPreset )
 	synthv1widget::updateDirtyPreset(bDirtyPreset);
 
 #ifdef CONFIG_NSM
-	if (m_pNsmClient && m_pNsmClient->is_active())
-		m_pNsmClient->dirty(true); // as far as NSM goes, we're always filthy!
+	if (m_pNsmClient && m_pNsmClient->is_active() && bDirtyPreset)
+		m_pNsmClient->dirty(true);
 #endif
 }
 
